>From 1f99b1603966af504faa24dc72a5371448300ec7 Mon Sep 17 00:00:00 2001
From: Felipe Sateler <fsateler@debian.org>
Date: Sat, 22 Oct 2016 21:15:26 -0300
Subject: [PATCH 1/2] dh_systemd_enable: refactor unit installation logic into
 a subroutine

---
 dh_systemd_enable | 64 ++++++++++++++-----------------------------------------
 1 file changed, 16 insertions(+), 48 deletions(-)

diff --git a/dh_systemd_enable b/dh_systemd_enable
index 09093f0..faa5650 100755
--- a/dh_systemd_enable
+++ b/dh_systemd_enable
@@ -102,6 +102,15 @@ sub contains_install_section {
 	return 0;
 }
 
+sub install_unit {
+	my ($package, $script, $pkgsuffix, $path, $installsuffix) = @_;
+	$installsuffix = $installsuffix || $pkgsuffix;
+	my $unit=pkgfile("$package", $pkgsuffix);
+	return if $unit eq '';
+	install_dir($path);
+	install_file($unit, "$path/$script.$installsuffix");
+}
+
 # PROMISE: DH NOOP WITHOUT tmp(lib/systemd/system) mount path service socket target tmpfile
 
 foreach my $package (@{$dh{DOPACKAGES}}) {
@@ -138,54 +147,13 @@ foreach my $package (@{$dh{DOPACKAGES}}) {
 		$script=$package;
 	}
 
-	my $service=pkgfile($package,"service");
-	if ($service ne '') {
-		my $path="$tmpdir/lib/systemd/system";
-		install_dir($path);
-
-		install_file($service, "$path/$script.service");
-	}
-
-	my $template=pkgfile("$package@","service");
-	if ($template ne '') {
-		my $path="$tmpdir/lib/systemd/system";
-		install_dir($path);
-		install_file($template, "$path/$script@.service");
-	}
-
-	my $target=pkgfile($package,"target");
-	if ($target ne '') {
-		my $path="$tmpdir/lib/systemd/system";
-		install_dir($path);
-		install_file($target, "$path/$script.target");
-	}
-
-	my $socket=pkgfile($package,"socket");
-	if ($socket ne '') {
-		my $path="$tmpdir/lib/systemd/system";
-		install_dir($path);
-		install_file($socket, "$path/$script.socket");
-	}
-
-	my $tmpfile=pkgfile($package,"tmpfile");
-	if ($tmpfile ne '') {
-		my $path="$tmpdir/usr/lib/tmpfiles.d";
-		install_dir($path);
-		install_file($tmpfile, "$path/$script.conf");
-	}
-
-	my $mount=pkgfile($package,"mount");
-	if ($mount ne '') {
-		my $path="$tmpdir/usr/lib/system";
-		install_dir($path);
-		install_file($mount, "$path/$script.mount");
-	}
-
-	my $pathunit=pkgfile($package,"path");
-	if ($pathunit ne '') {
-		my $path="$tmpdir/lib/systemd/system";
-		install_dir($path);
-		install_file($pathunit, "$path/$script.path");
+	foreach my $suffix ('', '@') {
+		install_unit("$package$suffix", $script, "service", "$tmpdir/lib/systemd/system");
+		install_unit("$package$suffix", $script, "target", "$tmpdir/lib/systemd/system");
+		install_unit("$package$suffix", $script, "socket", "$tmpdir/lib/systemd/system");
+		install_unit("$package$suffix", $script, "mount", "$tmpdir/lib/systemd/system");
+		install_unit("$package$suffix", $script, "path", "$tmpdir/lib/systemd/system");
+		install_unit("$package$suffix", $script, "tmpfile", "$tmpdir/lib/systemd/system", "conf");
 	}
 
 	find({
-- 
2.9.3

